function  [fitme] = findedge2(cent, nlin, order, prob)
% [fitme] = findedge2(cent, nlin, order,prob)
% fit linear equation to data, written to process edge location array
%   cent = array of (centroid) values
%   nlin = length of cent
%   order = polynominal fit order, 1 = linear
%   prob = probability [0 -1] for the optional chi-squatred test for outlier rejection
%        = 0 (default) no outlier rejection
%   fitme is model from the least-square fit
%    x = f(cent(x))
%  Note that this is the inverse of the usual cent(x) = int + slope*x
%  form
% Peter Burns   21 dec 2010
% Copyright (c) Photographic & Imaging Manufacturers Association
if nargin <4
    prob = 0;
end
if nargin <3
    order = 1;
end

index = 1:nlin; %%%%%%%%%%%%%%%%
 fitme = polyfit(index, cent, order); % x = f(y)
 
if prob ~=0;
    disp('outlier rejection')
 y = polyval( fitme, index);
 res = cent-y;
 sig = std(res);
 
 val = sqrt(chi2inv(prob, 1))*sig;
 xx =find(abs(res) < val);
% disp( [num2str(length(cent)),'  ', num2str(length(xx))] )
 
 fitme = polyfit(index(xx), cent(xx), order);
end
 %plot(index,cent,'*'), hold on,
 %plot(index,y,'+'), hold off
 
return
